@@ -223,7 +223,7 @@ impl_GetChildren (DBusConnection *bus,
                                             &iter_struct);
           dbus_message_iter_append_basic (&iter_struct, DBUS_TYPE_STRING,
                                           &child_name);
-          dbus_message_iter_append_basic (&iter_struct, DBUS_TYPE_STRING,
+          dbus_message_iter_append_basic (&iter_struct, DBUS_TYPE_OBJECT_PATH,
                                           &child_path);
           dbus_message_iter_close_container (&iter_array, &iter_struct);
           g_free (child_name);
@@ -568,6 +568,16 @@ impl_get_AccessibleId (DBusMessageIter *iter, void *user_data)
   return droute_return_v_string (iter, atk_object_get_accessible_id (object));
 }
 
+static dbus_bool_t
+impl_get_HelpText (DBusMessageIter *iter, void *user_data)
+{
+  AtkObject *object = (AtkObject *) user_data;
+
+  g_return_val_if_fail (ATK_IS_OBJECT (user_data), FALSE);
+
+  return droute_return_v_string (iter, atk_object_get_help_text (object));
+}
+
 static DRouteMethod methods[] = {
   { impl_GetChildAtIndex, "GetChildAtIndex" },
   { impl_GetChildren, "GetChildren" },
@@ -591,6 +601,7 @@ static DRouteProperty properties[] = {
   { impl_get_ChildCount, NULL, "ChildCount" },
   { impl_get_Attributes, NULL, "Attributes" },
   { impl_get_AccessibleId, NULL, "AccessibleId" },
+  { impl_get_HelpText, NULL, "HelpText" },
   { NULL, NULL, NULL }
 };
 
