@@ -417,6 +417,8 @@ typedef enum
  * should be in terms of speaking notifications. Currently, this is only used
  * for "notification" events, but it may be used for additional purposes
  * in the future.
+ *
+ * Since: 2.50
  */
 typedef enum
 {
@@ -803,12 +805,19 @@ AtkRole atk_role_register (const gchar *name);
 ATK_AVAILABLE_IN_2_8
 const gchar *atk_object_get_object_locale (AtkObject *accessible);
 
-ATK_AVAILABLE_IN_ALL
+ATK_AVAILABLE_IN_2_36
 const gchar *atk_object_get_accessible_id (AtkObject *accessible);
 
-ATK_AVAILABLE_IN_ALL
+ATK_AVAILABLE_IN_2_36
 void atk_object_set_accessible_id (AtkObject *accessible,
-                                   const gchar *name);
+                                   const gchar *id);
+
+ATK_AVAILABLE_IN_2_52
+const gchar *atk_object_get_help_text (AtkObject *accessible);
+
+ATK_AVAILABLE_IN_2_52
+void atk_object_set_help_text (AtkObject *accessible,
+                               const gchar *help_text);
 
 G_END_DECLS
 
