@@ -48,8 +48,6 @@ struct _AtspiDeviceLegacyPrivate
   guint virtual_mods_enabled;
   gboolean keyboard_grabbed;
   unsigned int numlock_physical_mask;
-  gint force_consume_mode;
-  struct timeval lock_toggle_time;
 };
 
 GObjectClass *device_legacy_parent_class;
@@ -100,38 +98,6 @@ key_cb (AtspiDeviceEvent *event, void *user_data)
   if (modifiers & (1 << ATSPI_MODIFIER_NUMLOCK))
     modifiers &= ~priv->numlock_physical_mask;
 
-  if (find_virtual_mapping (legacy_device, event->hw_code))
-    {
-      if (event->type == (AtspiEventType) ATSPI_KEY_PRESS)
-        {
-          if (priv->force_consume_mode == 0 || priv->force_consume_mode == 4)
-            priv->force_consume_mode = 1;
-          else if (priv->force_consume_mode == 2)
-            {
-              struct timeval tv_now, tv_diff;
-              gettimeofday (&tv_now, NULL);
-              timersub (&tv_now, &priv->lock_toggle_time, &tv_diff);
-              priv->force_consume_mode = (tv_diff.tv_sec == 0 && tv_diff.tv_usec < 500000) ? 3 : 1;
-            }
-        }
-      else
-        {
-          if (priv->force_consume_mode == 1)
-            {
-              gettimeofday (&priv->lock_toggle_time, NULL);
-              priv->force_consume_mode = 2;
-            }
-          else if (priv->force_consume_mode == 3)
-            priv->force_consume_mode = 4;
-        }
-      if (priv->force_consume_mode < 3)
-        ret = TRUE;
-    }
-  else
-    {
-      priv->force_consume_mode = 0;
-    }
-
   ret |= atspi_device_notify_key (ATSPI_DEVICE (legacy_device),
                                   event->type == (AtspiEventType) ATSPI_KEY_PRESS,
                                   event->hw_code, event->id,
@@ -297,6 +263,34 @@ atspi_device_legacy_ungrab_keyboard (AtspiDevice *device)
   priv->keyboard_grabbed = FALSE;
 }
 
+static void
+atspi_device_legacy_generate_mouse_event (AtspiDevice *device, AtspiAccessible *obj, gint x, gint y, const gchar *name, GError **error)
+{
+  AtspiPoint *p;
+
+  p = atspi_component_get_position (ATSPI_COMPONENT (obj), ATSPI_COORD_TYPE_SCREEN, error);
+  if (p->y == -1 && atspi_accessible_get_role (obj, NULL) == ATSPI_ROLE_APPLICATION)
+    {
+      g_clear_error (error);
+      g_free (p);
+      AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 0, NULL);
+      if (child)
+        {
+          p = atspi_component_get_position (ATSPI_COMPONENT (child), ATSPI_COORD_TYPE_SCREEN, error);
+          g_object_unref (child);
+        }
+    }
+
+  if (p->y == -1 || p->x == -1)
+    return;
+
+  x += p->x;
+  y += p->y;
+  g_free (p);
+
+  atspi_generate_mouse_event (x, y, name, error);
+}
+
 static void
 atspi_device_legacy_init (AtspiDeviceLegacy *device)
 {
@@ -340,6 +334,7 @@ atspi_device_legacy_class_init (AtspiDeviceLegacyClass *klass)
   device_class->get_locked_modifiers = atspi_device_legacy_get_locked_modifiers;
   device_class->grab_keyboard = atspi_device_legacy_grab_keyboard;
   device_class->ungrab_keyboard = atspi_device_legacy_ungrab_keyboard;
+  device_class->generate_mouse_event = atspi_device_legacy_generate_mouse_event;
 }
 
 /**
