@@ -31,7 +31,7 @@ atk_test_editable_text_get_editable_text_iface (TestAppFixture *fixture, gconstp
   AtspiAccessible *obj = fixture->root_obj;
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 1, NULL);
   AtspiEditableText *iface = atspi_accessible_get_editable_text_iface (child);
-  g_assert (iface != NULL);
+  g_assert_nonnull (iface);
   g_object_unref (iface);
   g_object_unref (child);
 }
@@ -44,9 +44,9 @@ atk_test_editable_text_set_attributes  (TestAppFixture *fixture, gconstpointer u
   AtspiAccessible *obj = fixture->root_obj;
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 1, NULL);
   AtspiEditableText *iface = atspi_accessible_get_editable_text_iface (child);
-  g_assert (iface != NULL);
+  g_assert_nonnull (iface);
 
-  g_assert (atspi_editable_text_set_attributes (iface, "attribute", 1, 2, NULL));
+  g_assert_true (atspi_editable_text_set_attributes (iface, "attribute", 1, 2, NULL));
 }
 #endif
 
@@ -56,8 +56,8 @@ atk_test_editable_text_insert_text (TestAppFixture *fixture, gconstpointer user_
   AtspiAccessible *obj = fixture->root_obj;
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 1, NULL);
   AtspiEditableText *iface = atspi_accessible_get_editable_text_iface (child);
-  g_assert (iface != NULL);
-  g_assert (atspi_editable_text_insert_text (iface, 0, "test_text", 9, NULL));
+  g_assert_nonnull (iface);
+  g_assert_true (atspi_editable_text_insert_text (iface, 0, "test_text", 9, NULL));
   g_object_unref (iface);
   g_object_unref (child);
 }
@@ -68,8 +68,8 @@ atk_test_editable_text_copy_text (TestAppFixture *fixture, gconstpointer user_da
   AtspiAccessible *obj = fixture->root_obj;
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 1, NULL);
   AtspiEditableText *iface = atspi_accessible_get_editable_text_iface (child);
-  g_assert (iface != NULL);
-  g_assert (atspi_editable_text_copy_text (iface, 1, 2, NULL));
+  g_assert_nonnull (iface);
+  g_assert_true (atspi_editable_text_copy_text (iface, 1, 2, NULL));
   g_object_unref (iface);
   g_object_unref (child);
 }
@@ -80,8 +80,8 @@ atk_test_editable_text_cut_text (TestAppFixture *fixture, gconstpointer user_dat
   AtspiAccessible *obj = fixture->root_obj;
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 1, NULL);
   AtspiEditableText *iface = atspi_accessible_get_editable_text_iface (child);
-  g_assert (iface != NULL);
-  g_assert (atspi_editable_text_cut_text (iface, 1, 2, NULL));
+  g_assert_nonnull (iface);
+  g_assert_true (atspi_editable_text_cut_text (iface, 1, 2, NULL));
   g_object_unref (iface);
   g_object_unref (child);
 }
@@ -92,9 +92,9 @@ atk_test_editable_text_delete_text (TestAppFixture *fixture, gconstpointer user_
   AtspiAccessible *obj = fixture->root_obj;
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 1, NULL);
   AtspiEditableText *iface = atspi_accessible_get_editable_text_iface (child);
-  g_assert (iface != NULL);
+  g_assert_nonnull (iface);
 
-  g_assert (atspi_editable_text_delete_text (iface, 1, 2, NULL));
+  g_assert_true (atspi_editable_text_delete_text (iface, 1, 2, NULL));
   g_object_unref (iface);
   g_object_unref (child);
 }
@@ -105,9 +105,9 @@ atk_test_editable_text_paste_text (TestAppFixture *fixture, gconstpointer user_d
   AtspiAccessible *obj = fixture->root_obj;
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 1, NULL);
   AtspiEditableText *iface = atspi_accessible_get_editable_text_iface (child);
-  g_assert (iface != NULL);
+  g_assert_nonnull (iface);
 
-  g_assert (atspi_editable_text_paste_text (iface, 2, NULL));
+  g_assert_true (atspi_editable_text_paste_text (iface, 2, NULL));
   g_object_unref (iface);
   g_object_unref (child);
 }
