@@ -27,9 +27,9 @@ static void
 atk_test_table_get_caption (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   AtspiAccessible *acc = atspi_table_get_caption (obj, NULL);
   check_name (acc, "caption name");
@@ -42,9 +42,9 @@ static void
 atk_test_table_get_summary (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   AtspiAccessible *acc = atspi_table_get_summary (obj, NULL);
   check_name (acc, "table summary name");
@@ -57,9 +57,9 @@ static void
 atk_test_table_get_n_columns (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   gint cnt = atspi_table_get_n_columns (obj, NULL);
   g_assert_cmpint (cnt, ==, 3);
@@ -71,9 +71,9 @@ static void
 atk_test_table_get_n_rows (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   gint cnt = atspi_table_get_n_rows (obj, NULL);
   g_assert_cmpint (cnt, ==, 4);
@@ -85,12 +85,12 @@ static void
 atk_test_table_get_accessible_at (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   AtspiAccessible *acc = atspi_table_get_accessible_at (obj, 0, 0, NULL);
-  g_assert (acc);
+  g_assert_nonnull (acc);
   check_name (acc, "cell 0/0");
   g_object_unref (acc);
 
@@ -105,9 +105,9 @@ static void
 atk_test_table_get_index_at (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
 
   gint cnt = atspi_table_get_index_at (obj, 0, 0, NULL);
@@ -126,9 +126,9 @@ static void
 atk_test_table_get_row_at_index (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
 
   gint cnt = atspi_table_get_row_at_index (obj, 1, NULL);
@@ -150,9 +150,9 @@ static void
 atk_test_table_get_column_at_index (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
 
   gint cnt = atspi_table_get_column_at_index (obj, 6, NULL);
@@ -171,16 +171,16 @@ static void
 atk_test_table_get_row_description (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   gchar *desc = atspi_table_get_row_description (obj, 0, NULL);
-  g_assert (desc);
+  g_assert_nonnull (desc);
   g_assert_cmpstr (desc, ==, "first row");
   g_free (desc);
   desc = atspi_table_get_row_description (obj, 2, NULL);
-  g_assert (desc);
+  g_assert_nonnull (desc);
   g_assert_cmpstr (desc, ==, "third row");
   g_free (desc);
   g_object_unref (obj);
@@ -191,16 +191,16 @@ static void
 atk_test_table_get_column_description (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   gchar *desc = atspi_table_get_column_description (obj, 0, NULL);
-  g_assert (desc);
+  g_assert_nonnull (desc);
   g_assert_cmpstr (desc, ==, "first column");
   g_free (desc);
   desc = atspi_table_get_column_description (obj, 2, NULL);
-  g_assert (desc);
+  g_assert_nonnull (desc);
   g_assert_cmpstr (desc, ==, "third column");
   g_free (desc);
   g_object_unref (obj);
@@ -211,9 +211,9 @@ static void
 atk_test_table_get_row_extent_at (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   gint cnt = atspi_table_get_row_extent_at (obj, 1, 1, NULL);
   g_assert_cmpint (cnt, ==, 1);
@@ -225,9 +225,9 @@ static void
 atk_test_table_get_column_extent_at (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   gint cnt = atspi_table_get_column_extent_at (obj, 1, 1, NULL);
   g_assert_cmpint (cnt, ==, 1);
@@ -239,9 +239,9 @@ static void
 atk_test_table_get_row_header (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   AtspiAccessible *acc = atspi_table_get_row_header (obj, 0, NULL);
   check_name (acc, "row 1 header");
@@ -257,9 +257,9 @@ static void
 atk_test_table_get_column_header (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   AtspiAccessible *acc = atspi_table_get_column_header (obj, 0, NULL);
   check_name (acc, "column 1 header");
@@ -278,9 +278,9 @@ static void
 atk_test_table_get_n_selected_rows (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   gint cnt = atspi_table_get_n_selected_rows (obj, NULL);
   g_assert_cmpint (cnt, ==, 2);
@@ -292,12 +292,12 @@ static void
 atk_test_table_get_selected_rows (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   GArray *array = atspi_table_get_selected_rows (obj, NULL);
-  g_assert (array);
+  g_assert_nonnull (array);
   g_assert_cmpint (array->len, ==, 2);
   g_assert_cmpint (g_array_index (array, gint, 0), ==, 0);
   g_assert_cmpint (g_array_index (array, gint, 1), ==, 2);
@@ -310,12 +310,12 @@ static void
 atk_test_table_get_selected_columns (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   GArray *array = atspi_table_get_selected_columns (obj, NULL);
-  g_assert (array);
+  g_assert_nonnull (array);
   g_assert_cmpint (array->len, ==, 1);
   g_assert_cmpint (g_array_index (array, gint, 0), ==, 1);
 
@@ -328,12 +328,12 @@ static void
 atk_test_table_get_n_selected_columns (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
 
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
-  g_assert (obj);
+  g_assert_nonnull (obj);
   gint cnt = atspi_table_get_n_selected_columns (obj, NULL);
   g_assert_cmpint (cnt, ==, 1);
   g_object_unref (obj);
@@ -344,11 +344,11 @@ static void
 atk_test_table_is_row_selected (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
-  g_assert (obj);
+  g_assert_nonnull (obj);
   g_assert_true (atspi_table_is_row_selected (obj, 0, NULL));
   g_assert_false (atspi_table_is_row_selected (obj, 1, NULL));
   g_object_unref (obj);
@@ -359,9 +359,9 @@ static void
 atk_test_table_is_column_selected (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   g_assert_true (atspi_table_is_column_selected (obj, 1, NULL));
   g_assert_false (atspi_table_is_column_selected (obj, 0, NULL));
@@ -373,9 +373,9 @@ static void
 atk_test_table_add_row_selection (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   g_assert_false (atspi_table_is_row_selected (obj, 1, NULL));
   g_assert_true (atspi_table_add_row_selection (obj, 1, NULL));
@@ -388,9 +388,9 @@ static void
 atk_test_table_add_column_selection (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   g_assert_false (atspi_table_is_column_selected (obj, 2, NULL));
   g_assert_true (atspi_table_add_column_selection (obj, 2, NULL));
@@ -403,9 +403,9 @@ static void
 atk_test_table_remove_row_selection (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   g_assert_true (atspi_table_is_row_selected (obj, 2, NULL));
   g_assert_true (atspi_table_remove_row_selection (obj, 2, NULL));
@@ -418,9 +418,9 @@ static void
 atk_test_table_remove_column_selection (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   g_assert_true (atspi_table_is_column_selected (obj, 1, NULL));
   g_assert_true (atspi_table_remove_column_selection (obj, 1, NULL));
@@ -433,9 +433,9 @@ static void
 atk_test_table_get_row_column_extents_at_index (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   gint row;
   gint col;
@@ -457,9 +457,9 @@ static void
 atk_test_table_is_selected (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   g_assert_true (atspi_table_is_selected (obj, 0, 2, NULL));
   g_assert_false (atspi_table_is_selected (obj, 1, 0, NULL));
